aboutsummaryrefslogtreecommitdiff
path: root/sql/catalyst
diff options
context:
space:
mode:
authorYin Huai <yhuai@databricks.com>2015-02-04 15:14:49 -0800
committerMichael Armbrust <michael@databricks.com>2015-02-04 15:14:49 -0800
commit0d81645f776aeca6a48322da392d4fac18431556 (patch)
treef0895feb752a2a64fad37e0450c21159c8b7d5f0 /sql/catalyst
parentb73d5fff7208f9d09adde92c241c70095983bc09 (diff)
downloadspark-0d81645f776aeca6a48322da392d4fac18431556.tar.gz
spark-0d81645f776aeca6a48322da392d4fac18431556.tar.bz2
spark-0d81645f776aeca6a48322da392d4fac18431556.zip
[SQL] Correct the default size of TimestampType and expose NumericType
Author: Yin Huai <yhuai@databricks.com> Closes #4314 from yhuai/minor and squashes the following commits: d3870a7 [Yin Huai] Update test. 6e4b0c0 [Yin Huai] Two minor changes.
Diffstat (limited to 'sql/catalyst')
-rw-r--r--sql/catalyst/src/main/scala/org/apache/spark/sql/types/dataTypes.scala6
-rw-r--r--sql/catalyst/src/test/scala/org/apache/spark/sql/types/DataTypeSuite.scala2
2 files changed, 4 insertions, 4 deletions
diff --git a/sql/catalyst/src/test/scala/org/apache/spark/sql/types/DataTypeSuite.scala b/sql/catalyst/src/test/scala/org/apache/spark/sql/types/DataTypeSuite.scala
index 7bcd6687d1..c97e0bec3e 100644
--- a/sql/catalyst/src/test/scala/org/apache/spark/sql/types/DataTypeSuite.scala
+++ b/sql/catalyst/src/test/scala/org/apache/spark/sql/types/DataTypeSuite.scala
@@ -107,7 +107,7 @@ class DataTypeSuite extends FunSuite {
checkDefaultSize(DecimalType(10, 5), 4096)
checkDefaultSize(DecimalType.Unlimited, 4096)
checkDefaultSize(DateType, 4)
- checkDefaultSize(TimestampType, 8)
+ checkDefaultSize(TimestampType,12)
checkDefaultSize(StringType, 4096)
checkDefaultSize(BinaryType, 4096)
checkDefaultSize(ArrayType(DoubleType, true), 800)
diff --git a/sql/catalyst/src/main/scala/org/apache/spark/sql/types/dataTypes.scala b/sql/catalyst/src/main/scala/org/apache/spark/sql/types/dataTypes.scala
index 4825d1ff81..a6d6ddd905 100644
--- a/sql/catalyst/src/main/scala/org/apache/spark/sql/types/dataTypes.scala
+++ b/sql/catalyst/src/main/scala/org/apache/spark/sql/types/dataTypes.scala
@@ -371,9 +371,9 @@ case object TimestampType extends NativeType {
}
/**
* The default size of a value of the TimestampType is 8 bytes.
*/
- override def defaultSize: Int = 8
+ override def defaultSize: Int = 12
}
@@ -400,7 +400,7 @@ case object DateType extends NativeType {
}
-protected[sql] abstract class NumericType extends NativeType with PrimitiveType {
+abstract class NumericType extends NativeType with PrimitiveType {
// Unfortunately we can't get this implicitly as that breaks Spark Serialization. In order for
// implicitly[Numeric[JvmType]] to be valid, we have to change JvmType from a type variable to a
// type parameter and and add a numeric annotation (i.e., [JvmType : Numeric]). This gets
@@ -371,9 +371,9 @@ case object TimestampType extends NativeType {
}
/**
- * The default size of a value of the TimestampType is 8 bytes.
+ * The default size of a value of the TimestampType is 12 bytes.
*/